# Changelog

## [3.1.0a1](https://github.com/OpenVoiceOS/OVOS-workshop/tree/3.1.0a1) (2024-11-20)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/3.0.1...3.1.0a1)

**Merged pull requests:**

- feat:utterance\_modifiers [\#291](https://github.com/OpenVoiceOS/OVOS-workshop/pull/291) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
